/* ***************************************************************************
 *
 *	This program is free software; you can redistribute it and/or modify it
 * 	under the terms of the Shared Code License (SCL) version 1.0 as published
 *	by www.IntellectualHeaven.com. You should have received a copy of the SCL
 *	1.0 license, look for file license.txt, along with this software; if not,
 *	then please write to x_pankaj_x@intellectualheaven.com for an electronic
 *	copy of the same.
 *
 * File name:
 * 		SfCuiView.cpp
 * 
 * Description:
 * 		This file implements the CUI view functionality for the application.
 *		It handles all the console UI code and also the packet display code
 * 	
 * Revision:
 * --------------------------------------------------------------------------
 *		2005-04-24	xpankajx@intellectualheaven.com
 *		First version
 * --------------------------------------------------------------------------
 * 	Copyright (c) : Pankaj Garg
 * **************************************************************************/

// System-Includes!!!
#include <windows.h>
#include <stdio.h>

// Local-Includes!!!
#include "sfcuiview.h"



/****************************************************************************
 *  FUNCTION NAME:  SfUtilChangeTextClr
 *
 *  DESCRIPTION:    Change the color of the console window
 *
 *  INPUTS:         colorNew - New color of console
 *
 *  RETURNS:		previous color of the console
 ***************************************************************************/
WORD
SfUtilChangeTextClr(
	WORD colorNew)
{
	HANDLE conOutputHandle = GetStdHandle(STD_OUTPUT_HANDLE);

	CONSOLE_SCREEN_BUFFER_INFO consoleInfo;

	GetConsoleScreenBufferInfo(
					conOutputHandle,
					&consoleInfo);

	SetConsoleTextAttribute(
						conOutputHandle,
						colorNew);

	return consoleInfo.wAttributes;
}



/****************************************************************************
 *  FUNCTION NAME:  HandleNewPacket
 *
 *  DESCRIPTION:    Called whenever we receive a new packet
 *
 *  INPUTS:         pPacketData - Information about the new packet
 *
 *  RETURNS:		None
 ***************************************************************************/
void
CSfCuiView::HandleNewPacket(
	PacketData *pPacketData)
{
	std::wstring hexDump;
	PrepareHexDump(hexDump, pPacketData->data, 0, pPacketData->length, 24);

	if (pPacketData->action == ACTION_ACCESS_GRANTED)
	{
		SfUtilChangeTextClr(FOREGROUND_GREEN | FOREGROUND_INTENSITY);
	}
	else if (pPacketData->action == ACTION_ACCESS_DENIED)
	{
		SfUtilChangeTextClr(FOREGROUND_RED | FOREGROUND_INTENSITY);
	}

	wprintf(L"%s\n", hexDump.c_str());

	SfUtilChangeTextClr(FOREGROUND_WHITE);
}

